Welcome to filemanipulator, a small module built to aid with some file operations which may be useful.
It's a simple module, but can sometimes come in useful, particularly with file management.

To update to the latest version, either set 'autoupdates' in the \__init__.py file to True, for the module
to automatically update whenver a new version is available on GitHub, or run the \__init__.py file as its own
script, triggering an automatic update.

Please ensure file editing permissions are granted to Python for this module to work properly.
